#!/usr/bin/perl -w
# @(#) $Id$

use strict;
use warnings;

use Test::More;

eval "use Test::Pod 1.00";
plan skip_all => "Test::Pod 1.00 required for testing POD" if $@;
all_pod_files_ok();

# vim: set ai et sw=4 syntax=perl :
